==> treeland-debug-0.7.3-3-x86_64.pkg.tar.zst: usr/src/debug/treeland/treeland/src/.qt/rcc/qrc_libtreeland_raw_qml_0_extra_qmldirs.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x0,0x1a,
  0x70,
  0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x54,
  0x72,0x65,0x65,0x6c,0x61,0x6e,0x64,0x2f,0xa,
    // qmldir
  0x0,0x0,0x0,0x1a,
  0x70,
  0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x54,
  0x72,0x65,0x65,0x6c,0x61,0x6e,0x64,0x2f,0xa,
    // qmldir
  0x0,0x0,0x0,0x1a,
  0x70,
  0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x54,
  0x72,0x65,0x65,0x6c,0x61,0x6e,0x64,0x2f,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Treeland
  0x0,0x8,
  0x8,0xbc,0x2f,0x24,
  0x0,0x54,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // core
  0x0,0x4,
  0x0,0x6,0xa6,0x85,
  0x0,0x63,
  0x0,0x6f,0x0,0x72,0x0,0x65,
    // Animations
  0x0,0xa,
  0x3,0x84,0x10,0x53,
  0x0,0x41,
  0x0,0x6e,0x0,0x69,0x0,0x6d,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // Effects
  0x0,0x7,
  0xb,0xcc,0xba,0x33,
  0x0,0x45,
  0x0,0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland/core
  0x0,0x0,0x0,0x2c,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland/core/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland/core/qml/Animations
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xa,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland/core/qml/qmldir
  0x0,0x0,0x0,0x68,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland/core/qml/Effects
  0x0,0x0,0x0,0x54,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x9,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland/core/qml/Effects/qmldir
  0x0,0x0,0x0,0x68,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1e,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,
  // :/qt/qml/Treeland/core/qml/Animations/qmldir
  0x0,0x0,0x0,0x68,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3c,
0x0,0x0,0x1,0x99,0xcf,0x87,0x90,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_libtreeland_raw_qml_0_extra_qmldirs)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_libtreeland_raw_qml_0_extra_qmldirs)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_libtreeland_raw_qml_0_extra_qmldirs)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_libtreeland_raw_qml_0_extra_qmldirs)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_libtreeland_raw_qml_0_extra_qmldirs)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_libtreeland_raw_qml_0_extra_qmldirs)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> treeland-debug-0.7.4-1-x86_64.pkg.tar.zst: usr/src/debug/treeland/treeland/src/.qt/rcc/qrc_libtreeland_raw_qml_0_extra_qmldirs.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x0,0x1a,
  0x70,
  0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x54,
  0x72,0x65,0x65,0x6c,0x61,0x6e,0x64,0x2f,0xa,
    // qmldir
  0x0,0x0,0x0,0x1a,
  0x70,
  0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x54,
  0x72,0x65,0x65,0x6c,0x61,0x6e,0x64,0x2f,0xa,
    // qmldir
  0x0,0x0,0x0,0x1a,
  0x70,
  0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x71,0x74,0x2f,0x71,0x6d,0x6c,0x2f,0x54,
  0x72,0x65,0x65,0x6c,0x61,0x6e,0x64,0x2f,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Treeland
  0x0,0x8,
  0x8,0xbc,0x2f,0x24,
  0x0,0x54,
  0x0,0x72,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,0x61,0x0,0x6e,0x0,0x64,
    // core
  0x0,0x4,
  0x0,0x6,0xa6,0x85,
  0x0,0x63,
  0x0,0x6f,0x0,0x72,0x0,0x65,
    // Animations
  0x0,0xa,
  0x3,0x84,0x10,0x53,
  0x0,0x41,
  0x0,0x6e,0x0,0x69,0x0,0x6d,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // Effects
  0x0,0x7,
  0xb,0xcc,0xba,0x33,
  0x0,0x45,
  0x0,0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland/core
  0x0,0x0,0x0,0x2c,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland/core/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland/core/qml/Animations
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xa,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland/core/qml/qmldir
  0x0,0x0,0x0,0x68,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland/core/qml/Effects
  0x0,0x0,0x0,0x54,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x9,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland/core/qml/Effects/qmldir
  0x0,0x0,0x0,0x68,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1e,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,
  // :/qt/qml/Treeland/core/qml/Animations/qmldir
  0x0,0x0,0x0,0x68,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3c,
0x0,0x0,0x1,0x99,0xfa,0x67,0xe5,0x68,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_libtreeland_raw_qml_0_extra_qmldirs)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_libtreeland_raw_qml_0_extra_qmldirs)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_libtreeland_raw_qml_0_extra_qmldirs)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_libtreeland_raw_qml_0_extra_qmldirs)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_libtreeland_raw_qml_0_extra_qmldirs)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_libtreeland_raw_qml_0_extra_qmldirs)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
